
RoadMasterSettings = {}
local RoadMasterSettings_mt = Class(RoadMasterSettings, ScreenElement)
function RoadMasterSettings.register()
	local self = RoadMasterSettings.new()
	g_gui:loadGui(g_roadMasterDirectory .. "gui/dialogs/RoadMasterSettings.xml", "RoadMasterSettings", self)
	RoadMasterSettings.INSTANCE = self
end
function RoadMasterSettings.show(vehicle)
	if RoadMasterSettings.INSTANCE ~= nil then
		local self = RoadMasterSettings.INSTANCE
		self.vehicle = vehicle
		g_gui:showDialog("RoadMasterSettings")
	end
end
function RoadMasterSettings.new(target, custom_mt)
	local self = DialogElement.new(target, custom_mt or RoadMasterSettings_mt)
	self.vehicle = nil
	self.i18n = g_i18n.modEnvironments[g_roadMasterModName]
	return self
end
function RoadMasterSettings:delete()
end
function RoadMasterSettings:setVehicle(vehicle)
  self.vehicle = vehicle
end
function RoadMasterSettings:onOpen()
	RoadMasterSettings:superClass().onOpen(self)
	local v59 = true
	for _, element in pairs(self.settingsboxLayout.elements) do
		if element.name == "sectionHeader" then
			v59 = true
		elseif element:getIsVisible() then
			local colorcode = RoadMasterSettings.COLOR_ALTERNATING[v59]
			element:setImageColor(nil, unpack(colorcode))
			v59 = not v59
		end
	end
	local displayModeTable = {}
	table.insert(displayModeTable, self.i18n:getText("RM_setting_displayModeOption1"))
	table.insert(displayModeTable, self.i18n:getText("RM_setting_displayModeOption2"))
	self.multidisplayMode:setTexts(displayModeTable)
	local fuelDiesel_current = -1
	local fuelElectric_current = -1
	local fuelAdblue_current = -1
	local fuelMethane_current = -1
	local specfillUnit = self.vehicle.spec_fillUnit
	if self.vehicle.getConsumerFillUnitIndex ~= nil then
		if g_modIsLoaded["FS25_gameplay_Real_Vehicle_Breakdowns"] then
			if self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL) ~= nil and self.vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE) ~= nil then
				if specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL)] ~= nil then
					fuelDiesel_max = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL)].capacity
					fuelDiesel_current = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL)].fillLevel
				end
			end
		else
			if self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL) ~= nil then
				if specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL)] ~= nil then
					fuelDiesel_max = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL)].capacity
					fuelDiesel_current = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL)].fillLevel
				end
			end
		end
		if self.vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE) ~= nil and self.vehicle:getConsumerFillUnitIndex(FillType.DIESEL) == nil then
			if specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE)] ~= nil then
				fuelElectric_max = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE)].capacity
				fuelElectric_current = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE)].fillLevel
			end
		end
		if self.vehicle:getConsumerFillUnitIndex(FillType.DEF) ~= nil then
			if specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DEF)] ~= nil then
				fuelAdblue_max = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DEF)].capacity
				fuelAdblue_current = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.DEF)].fillLevel
			end
		end
		if self.vehicle:getConsumerFillUnitIndex(FillType.METHANE) ~= nil then
			if specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.METHANE)] ~= nil then
				fuelMethane_max = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.METHANE)].capacity
				fuelMethane_current = specfillUnit.fillUnits[self.vehicle:getConsumerFillUnitIndex(FillType.METHANE)].fillLevel
			end
		end
	end
	local distanceunitText = g_i18n:getMeasuringUnit(false)
	local speedunitText = g_i18n:getSpeedMeasuringUnit()
	local remainingOperatingtime = 0
	local remainingOperatingtimeString = "-/-"
	local fuelText = "-/-"
	local averageSpeedString = "-/- "..speedunitText
	local distanceString = "-/- "..distanceunitText
	local motorState = self.vehicle:getMotorState()
	if motorState == MotorState.ON then
		if fuelElectric_current >= 0 then
			remainingOperatingtime = fuelElectric_current / self.vehicle.spec_motorized.lastFuelUsage
		else
			if self.vehicle.spec_motorized.lastFuelUsage > 0 then
				remainingOperatingtime = fuelDiesel_current / self.vehicle.spec_motorized.lastFuelUsage
				remainingOperatingtimeString = string.format("%.2f"..g_i18n:getText("RM_setting_hours"), remainingOperatingtime)
				fuelText = string.format("%.1f / %.1f L", fuelDiesel_current, fuelDiesel_max)
			end
		end
		averageSpeedString = string.format("%.0f "..speedunitText, g_i18n:getSpeed(self.vehicle:getAverageSpeed()))
		local distance = remainingOperatingtime * self.vehicle:getAverageSpeed()
		distanceString = string.format("%.1f "..distanceunitText, g_i18n:getSpeed(distance))
	end
	self.remainingOpTime:setText(remainingOperatingtimeString)
	self.averageSpeedText:setText(averageSpeedString)
	self.distanceText:setText(distanceString)
	self.fuelLevel:setText(fuelText)
	self:updateValues()
end
function RoadMasterSettings:updateValues()
	self.checkshowOdometer:setIsChecked(self.vehicle:getshowOdometer())
	self.checkshowFuelUsage:setIsChecked(self.vehicle:getshowFuelUsage())
	self.checkshowTemp:setIsChecked(self.vehicle:getshowTemp())
	self.checkshowRpm:setIsChecked(self.vehicle:getshowRpm())
	self.multidisplayMode:setState(self.vehicle:getdisplayMode())
	self.checkgameOpHours:setIsChecked(self.vehicle:getgameOpHours())
end
function RoadMasterSettings:onClickOk()
	if self.vehicle == nil then return end
	self.vehicle.spec_roadMaster.showOdometer = self.checkshowOdometer:getIsChecked()
	self.vehicle.spec_roadMaster.showFuelUsage = self.checkshowFuelUsage:getIsChecked()
	self.vehicle.spec_roadMaster.showTemp = self.checkshowTemp:getIsChecked()
	self.vehicle.spec_roadMaster.showRpm = self.checkshowRpm:getIsChecked()
	self.vehicle.spec_roadMaster.displayMode = self.multidisplayMode:getState()
	self.vehicle.spec_roadMaster.gameOpHours = self.checkgameOpHours:getIsChecked()
	g_gui:closeDialogByName("RoadMasterSettings")
end
function RoadMasterSettings:onClickBack()
	g_gui:closeDialogByName("RoadMasterSettings")
end
RoadMasterSettings.COLOR_ALTERNATING = {
	[true] = {
		0.02956,
		0.02956,
		0.02956,
		0.6
	},
	[false] = {
		0.02956,
		0.02956,
		0.02956,
		0.2
	}
}