
RoadMasterHUD = {}
local RoadMasterHUD_mt = Class(RoadMasterHUD, HUDDisplay)
RoadMasterHUD.COLOR = {
	TEXT = { 1, 1, 1, 1 },
	TEXT_BACKGROUND = { 1, 1, 1, 0.3 }
}
function RoadMasterHUD:new()
	local self = RoadMasterHUD:superClass().new(RoadMasterHUD_mt)
	self.vehicle = nil
	self.isVehicleDrawSafe = false
	return self
end
function RoadMasterHUD:delete()
	if self.vehicle ~= nil then
		self.vehicle = nil
	end
	self.isVehicleDrawSafe = false
	RoadMasterHUD:superClass().delete(self)
end
function RoadMasterHUD:storeScaledValues()
	self.rm_odometerTextOffsetX, self.rm_odometerTextOffsetY = self:scalePixelValuesToScreenVector(43, -41)
	self.rm_tripTextOffsetX, self.rm_tripTextOffsetY = self:scalePixelValuesToScreenVector(29, -41)
	self.rm_odometerTextSize = self:scalePixelToScreenHeight(14)
	self.rm_tripOffsetX, self.rm_tripOffsetY = self:scalePixelValuesToScreenVector(-6, -30)
	self.rm_tripSize = self:scalePixelToScreenHeight(9)
	self.rm_tempTextOffsetX, self.rm_tempTextOffsetY = self:scalePixelValuesToScreenVector(52, -59)
	self.rm_tempTextSize = self:scalePixelToScreenHeight(10)
	self.rm_rpmTextOffsetX, self.rm_rpmTextOffsetY = self:scalePixelValuesToScreenVector(-54, -59)
	self.rm_rpmTextSize = self:scalePixelToScreenHeight(10)
	self.rm_fuelTextOffsetX, self.rm_fuelTextOffsetY = self:scalePixelValuesToScreenVector(12, 5)
	self.rm_fuelTextSize = self:scalePixelToScreenHeight(14)
end
function RoadMasterHUD:setVehicle(vehicle)
	self.vehicle = nil
	local hasVehicle = vehicle ~= nil
	local isMotorized = hasVehicle and vehicle.spec_motorized ~= nil
	if hasVehicle and isMotorized then
		self.vehicle = vehicle
	end
	self:setVisible(self.vehicle ~= nil)
	self.isVehicleDrawSafe = false
end
function RoadMasterHUD:update(dt)
	RoadMasterHUD:superClass().update(self, dt)
	if self.vehicle ~= nil then
		self.isVehicleDrawSafe = true
	else
		self.isVehicleDrawSafe = false	
	end
end
function RoadMasterHUD:draw()
	local vehicle = self.vehicle
	if vehicle == nil or not self.isVehicleDrawSafe then
		return
	end
	local rm_speedBgX, rm_speedBgY = g_currentMission.hud.speedMeter.speedBg:getPosition()
	local rm_posX = rm_speedBgX + g_currentMission.hud.speedMeter.speedGaugeCenterOffsetX
	local rm_posY = rm_speedBgY + g_currentMission.hud.speedMeter.speedGaugeCenterOffsetY
	if vehicle.spec_roadMaster.showOdometer then
		local unit = g_i18n:getMeasuringUnit()
		local textBG = ""
		local text = ""
		local odometerTextPosX = rm_posX + self.rm_odometerTextOffsetX - 0.012
		local odometerTextPosY = rm_posY + self.rm_odometerTextOffsetY
		local odometerUnitPosX = odometerTextPosX + 0.012
		local odometerUnitPosY = odometerTextPosY 
		if vehicle.spec_roadMaster.displayMode == 1 then
			local drivenDistance = vehicle:getOdometer()
			local distanceInKM = drivenDistance / 1000
			distanceInKM = distanceInKM % 999999
			local distance = g_i18n:getDistance(distanceInKM)
			textBG = string.format("%08.0f", distance)
			text = string.format("%.0f", distance)
		else
			local drivenDistance = vehicle:getTrip()
			local distanceInKM = drivenDistance / 1000
			distanceInKM = distanceInKM % 999.9
			local distance = g_i18n:getDistance(distanceInKM)
			distance = math.floor(distance * 10) / 10
			textBG = string.format("%05.1f", distance)
			text = string.format("%.1f", distance)
			odometerTextPosX = rm_posX + self.rm_tripTextOffsetX - 0.012
			odometerTextPosY = rm_posY + self.rm_tripTextOffsetY
			odometerUnitPosX = odometerTextPosX + 0.012
			odometerUnitPosY = odometerTextPosY
			local tripPosX = rm_posX + self.rm_tripOffsetX - 0.012
			local tripPosY = rm_posY + self.rm_tripOffsetY
			setTextAlignment(RenderText.ALIGN_RIGHT)
			setTextColor(1,1,1,1)
			renderText(tripPosX, tripPosY, self.rm_tripSize, "trip")
		end
		local textColor = RoadMasterHUD.COLOR.TEXT
		local textColorBG = RoadMasterHUD.COLOR.TEXT_BACKGROUND
		if vehicle.spec_motorized ~= nil then
			setTextBold(false)
			setTextAlignment(RenderText.ALIGN_RIGHT)
			setTextColor(unpack(HUD.COLOR.ACTIVE))
			renderText(odometerUnitPosX, odometerUnitPosY, self.rm_odometerTextSize, unit)
			setTextBold(false)
			setTextAlignment(RenderText.ALIGN_RIGHT)
			setTextColor(textColorBG[1], textColorBG[2], textColorBG[3], textColorBG[4])
			renderText(odometerTextPosX, odometerTextPosY, self.rm_odometerTextSize, textBG)
			setTextColor(textColor[1], textColor[2], textColor[3], textColor[4])
			renderText(odometerTextPosX, odometerTextPosY, self.rm_odometerTextSize, text)
		end
	end
	if vehicle.spec_roadMaster.showTemp then	
		if vehicle.spec_motorized ~= nil and vehicle.isServer then
			local _useF = g_gameSettings:getValue(GameSettings.SETTING.USE_FAHRENHEIT)
			local _s = "C"
			if _useF then _s = "F" end
			local temp_txt1 = "0"
			local temp_txt2 = "\n°" .. _s
			local motorState = vehicle:getMotorState()
			if motorState == MotorState.ON then
				local _value = vehicle.spec_motorized.motorTemperature.value
				if _useF then _value = _value * 1.8 + 32 end
				temp_txt1 = string.format("%i", _value)
			end
			local tempTextOffsetX = rm_posX + self.rm_tempTextOffsetX 
			local tempTextOffsetY = rm_posY + self.rm_tempTextOffsetY
			setTextColor(1,1,1,1)
			setTextAlignment(RenderText.ALIGN_CENTER)
			setTextVerticalAlignment(RenderText.VERTICAL_ALIGN_TOP)
			setTextBold(true)
			renderText(tempTextOffsetX, tempTextOffsetY, self.rm_tempTextSize, temp_txt1)
			setTextColor(unpack(HUD.COLOR.ACTIVE))
			renderText(tempTextOffsetX, tempTextOffsetY, self.rm_tempTextSize, temp_txt2)
		end
	end
	if vehicle.spec_roadMaster.showRpm then
		if vehicle.spec_motorized ~= nil and vehicle.isServer then
			local rpm_txt1 = "0"
			local rpm_txt2 = "\nrpm"
			local motorState = vehicle:getMotorState()
			if motorState == MotorState.ON then
				rpm_txt1 = string.format("%i", vehicle.spec_motorized:getMotorRpmReal())
			end
			local rpmTextOffsetX = rm_posX + self.rm_rpmTextOffsetX 
			local rpmTextOffsetY = rm_posY + self.rm_rpmTextOffsetY
			setTextColor(1,1,1,1)
			setTextAlignment(RenderText.ALIGN_CENTER)
			setTextVerticalAlignment(RenderText.VERTICAL_ALIGN_TOP)
			setTextBold(true)
			renderText(rpmTextOffsetX, rpmTextOffsetY, self.rm_rpmTextSize, rpm_txt1)
			setTextColor(unpack(HUD.COLOR.ACTIVE))
			renderText(rpmTextOffsetX, rpmTextOffsetY + 0.002, self.rm_rpmTextSize, rpm_txt2)
		end
	end
	if vehicle.spec_roadMaster.showFuelUsage then
		local motorState = vehicle:getMotorState()
		if motorState == MotorState.ON and vehicle.spec_fillUnit ~= nil and vehicle.isServer then
			local fuelDiesel_current = -1
			local fuelElectric_current = -1
			local fuelAdblue_current = -1
			local fuelMethane_current = -1
			local specfillUnit = vehicle.spec_fillUnit
			if vehicle.getConsumerFillUnitIndex ~= nil then
				if vehicle:getConsumerFillUnitIndex(FillType.DIESEL) ~= nil and vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE) ~= nil then
					if specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.DIESEL)] ~= nil then
						fuelDiesel_max = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.DIESEL)].capacity
						fuelDiesel_current = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.DIESEL)].fillLevel
					end
				end
				if vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE) ~= nil and vehicle:getConsumerFillUnitIndex(FillType.DIESEL) == nil then
					if specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE)] ~= nil then
						fuelElectric_max = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE)].capacity
						fuelElectric_current = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.ELECTRICCHARGE)].fillLevel
					end
				end
				if vehicle:getConsumerFillUnitIndex(FillType.DEF) ~= nil then
					if specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.DEF)] ~= nil then
						fuelAdblue_max = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.DEF)].capacity
						fuelAdblue_current = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.DEF)].fillLevel
					end
				end
				if vehicle:getConsumerFillUnitIndex(FillType.METHANE) ~= nil then
					if specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.METHANE)] ~= nil then
						fuelMethane_max = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.METHANE)].capacity
						fuelMethane_current = specfillUnit.fillUnits[vehicle:getConsumerFillUnitIndex(FillType.METHANE)].fillLevel
					end
				end
			end
			local fuel_txt1 = ""
			local fuel_txt2 = ""
			if fuelElectric_current >= 0 then
				fuel_txt1 = "kW/h"
				fuel_txt2 = string.format("%.1f", vehicle.spec_motorized.lastFuelUsage)
			else
				fuel_txt1 = "l/h"
				fuel_txt2 = string.format("%.1f", vehicle.spec_motorized.lastFuelUsage)
			end
			local fuelIconX, fuelIconY = g_currentMission.hud.speedMeter.fuelIcon:getPosition()
			local fuelTextOffsetX = fuelIconX + self.rm_fuelTextOffsetX - 0.001
			local fuelTextOffsetX_ = fuelIconX + self.rm_fuelTextOffsetX + 0.001
			local fuelTextOffsetY = fuelIconY + self.rm_fuelTextOffsetY
			setTextAlignment(RenderText.ALIGN_LEFT)
			setTextVerticalAlignment(RenderText.VERTICAL_ALIGN_TOP)
			setTextBold(true)
			setTextColor(unpack(HUD.COLOR.ACTIVE))
			renderText(fuelTextOffsetX_, fuelTextOffsetY, self.rm_fuelTextSize, fuel_txt1)
			setTextAlignment(RenderText.ALIGN_RIGHT)
			setTextColor(1,1,1,1)
			renderText(fuelTextOffsetX, fuelTextOffsetY, self.rm_fuelTextSize, fuel_txt2)
		end
	end
	setTextColor(1,1,1,1)
	setTextAlignment(RenderText.ALIGN_LEFT)
	setTextVerticalAlignment(RenderText.VERTICAL_ALIGN_BASELINE)
	setTextBold(false)
end